@@ -14,10 +14,14 @@
 
 from .resource_save import resource_save
 from .resource_load import resource_load
+from .utils import save, load
 
 from .backends import *
 
 
-from kale.utils import log_utils
-log_utils.get_or_create_logger(module=__name__, name="marshalling")
-del log_utils
+from kale.common import logutils
+logutils.get_or_create_logger(module=__name__, name="marshalling",
+                              # XXX: Should we have this as default in
+                              # `get_or_create_logger`??
+                              log_path="kale.log")
+del logutils
